@@ -7,6 +7,7 @@ from functools import partial
 from typing import Callable, MutableMapping, Iterable, Union, Sized, Sequence
 
 from i2 import Sig, call_somewhat_forgivingly
+from i2.signatures import ch_variadics_to_non_variadic_kind
 from meshed.util import ValidationError, NameValidationError, mk_func_name
 from meshed.itools import add_edge
 
@@ -93,6 +94,17 @@ def basic_node_validator(func_node):
     )
 
 
+def handle_variadics(func):
+    func = ch_variadics_to_non_variadic_kind(func)
+    # sig = Sig(func)
+    # var_kw = sig.var_keyword_name
+
+    #   # may be always return the wrapped function
+    # # func.var_kw_name = var_kw # TODO add it when needed
+
+    return func
+
+
 # TODO: When 3.10, look into and possibly use match_args in to_dict and from_dict
 # TODO: Make FuncNode immutable (is there a way to use frozen=True with post_init?)
 # TODO: How to get a safe hash? Needs to be immutable only?
@@ -201,11 +213,12 @@ class FuncNode:
     bind: dict = field(default_factory=dict)
     out: str = field(default=None)
     func_label: str = field(default=None)  # TODO: Integrate more
-    write_output_into_scope: bool = True  # TODO: Do we really want to allow False?
+    # write_output_into_scope: bool = True  # TODO: Do we really want to allow False?
     names_maker: Callable = underscore_func_node_names_maker
     node_validator: Callable = basic_node_validator
 
     def __post_init__(self):
+        self.func = handle_variadics(self.func)
         _func_node_args_validation(func=self.func, name=self.name, out=self.out)
         self.name, self.out = self.names_maker(self.func, self.name, self.out)
         self.__name__ = self.name
@@ -261,7 +274,7 @@ class FuncNode:
     def __repr__(self):
         return f'FuncNode({self.synopsis_string(bind_info="hybrid")})'
 
-    def call_on_scope(self, scope: MutableMapping):
+    def call_on_scope(self, scope: MutableMapping, write_output_into_scope=True):
         """Call the function using the given scope both to source arguments and write
         results.
 
@@ -273,7 +286,7 @@ class FuncNode:
         output = call_somewhat_forgivingly(
             self.func, args, kwargs, enforce_sig=self.sig
         )
-        if self.write_output_into_scope:
+        if write_output_into_scope:
             scope[self.out] = output
         return output
 
